@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2004-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 2004-2007 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the demonstration applications of the Qt Toolkit.
 **
@@ -9,12 +9,25 @@
 ** and appearing in the file LICENSE.GPL included in the packaging of
 ** this file.  Please review the following information to ensure GNU
 ** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** http://trolltech.com/products/qt/licenses/licensing/opensource/
 **
 ** If you are unsure which license is appropriate for your use, please
 ** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
+** or contact the sales department at sales@trolltech.com.
+**
+** In addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.0, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
+**
+** In addition, as a special exception, Trolltech, as the sole copyright
+** holder for Qt Designer, grants users of the Qt/Eclipse Integration
+** plug-in the right for the Qt/Eclipse Integration to link to
+** functionality provided by Qt Designer and its related libraries.
+**
+** Trolltech reserves all rights not expressly granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -62,8 +75,7 @@ QModelIndex Model::parent(const QModelIndex &child) const
 
 int Model::rowCount(const QModelIndex &parent) const
 {
-    Q_UNUSED(parent);
-    return rc;
+    return (parent.isValid() && parent.column() != 0) ? 0 : rc;
 }
 
 int Model::columnCount(const QModelIndex &parent) const
@@ -74,12 +86,15 @@ int Model::columnCount(const QModelIndex &parent) const
 
 QVariant Model::data(const QModelIndex &index, int role) const
 {
-    static QIcon folder(QPixmap(":/images/folder.png"));
-
+    if (!index.isValid())
+        return QVariant();
     if (role == Qt::DisplayRole)
 	return "Item " + QString::number(index.row()) + ":" + QString::number(index.column());
-    if (role == Qt::DecorationRole)
-	return qVariantFromValue(folder);
+    if (role == Qt::DecorationRole) {
+        if (index.column() == 0)
+            return iconProvider.icon(QFileIconProvider::Folder);
+        return iconProvider.icon(QFileIconProvider::File);
+    }
     return QVariant();
 }
 
@@ -95,12 +110,15 @@ QVariant Model::headerData(int section, Qt::Orientation orientation, int role) c
 
 bool Model::hasChildren(const QModelIndex &parent) const
 {
-    Q_UNUSED(parent);
+    if (parent.isValid() && parent.column() != 0)
+        return false;
     return rc > 0 && cc > 0;
 }
 
-Qt::ItemFlags Model::flags(const QModelIndex &) const
+Qt::ItemFlags Model::flags(const QModelIndex &index) const
 {
+    if (!index.isValid())
+        return 0;
     return (Qt::ItemIsDragEnabled|Qt::ItemIsSelectable|Qt::ItemIsEnabled);
 }
 
