@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 2005-2007 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the demonstration applications of the Qt Toolkit.
 **
@@ -9,12 +9,25 @@
 ** and appearing in the file LICENSE.GPL included in the packaging of
 ** this file.  Please review the following information to ensure GNU
 ** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** http://trolltech.com/products/qt/licenses/licensing/opensource/
 **
 ** If you are unsure which license is appropriate for your use, please
 ** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
+** or contact the sales department at sales@trolltech.com.
+**
+** In addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.0, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
+**
+** In addition, as a special exception, Trolltech, as the sole copyright
+** holder for Qt Designer, grants users of the Qt/Eclipse Integration
+** plug-in the right for the Qt/Eclipse Integration to link to
+** functionality provided by Qt Designer and its related libraries.
+**
+** Trolltech reserves all rights not expressly granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -29,6 +42,18 @@
 #include <QPushButton>
 #include <QGroupBox>
 
+#if defined(QT_OPENGL_SUPPORT)
+#include <QGLWidget>
+class GLWidget : public QGLWidget
+{
+public:
+    GLWidget(QWidget *parent)
+        : QGLWidget(QGLFormat(QGL::SampleBuffers), parent) {}
+    void disableAutoBufferSwap() { setAutoBufferSwap(false); }
+    void paintEvent(QPaintEvent *) { parentWidget()->update(); }
+};
+#endif
+
 class QTextDocument;
 class QTextEdit;
 class QVBoxLayout;
@@ -50,17 +75,31 @@ public:
 
     bool preferImage() const { return m_prefer_image; }
 
+#if defined(QT_OPENGL_SUPPORT)
+    QGLWidget *glWidget() const { return glw; }
+#endif
+
 public slots:
     void setPreferImage(bool pi) { m_prefer_image = pi; }
     void setDescriptionEnabled(bool enabled);
     void showSource();
 
+#if defined(QT_OPENGL_SUPPORT)
+    void enableOpenGL(bool use_opengl);
+    bool usesOpenGL() { return m_use_opengl; }
+#endif
+
 signals:
     void descriptionEnabledChanged(bool);
 
 protected:
     void paintEvent(QPaintEvent *);
+    void resizeEvent(QResizeEvent *);
 
+#if defined(QT_OPENGL_SUPPORT)
+    GLWidget *glw;
+    bool m_use_opengl;
+#endif
     QPixmap m_tile;
 
     bool m_show_doc;
