@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2006 Trolltech AS. All rights reserved.
+** Copyright (C) 2005-2007 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
@@ -9,12 +9,25 @@
 ** and appearing in the file LICENSE.GPL included in the packaging of
 ** this file.  Please review the following information to ensure GNU
 ** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** http://trolltech.com/products/qt/licenses/licensing/opensource/
 **
 ** If you are unsure which license is appropriate for your use, please
 ** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
+** or contact the sales department at sales@trolltech.com.
+**
+** In addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.0, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
+**
+** In addition, as a special exception, Trolltech, as the sole copyright
+** holder for Qt Designer, grants users of the Qt/Eclipse Integration
+** plug-in the right for the Qt/Eclipse Integration to link to
+** functionality provided by Qt Designer and its related libraries.
+**
+** Trolltech reserves all rights not expressly granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -28,13 +41,13 @@
 
 MainWindow::MainWindow()
 {
-    workspace = new QWorkspace;
-    setCentralWidget(workspace);
-    connect(workspace, SIGNAL(windowActivated(QWidget *)),
+    mdiArea = new QMdiArea;
+    setCentralWidget(mdiArea);
+    connect(mdiArea, SIGNAL(subWindowActivated(QMdiSubWindow *)),
             this, SLOT(updateMenus()));
     windowMapper = new QSignalMapper(this);
     connect(windowMapper, SIGNAL(mapped(QWidget *)),
-            workspace, SLOT(setActiveWindow(QWidget *)));
+            this, SLOT(setActiveSubWindow(QWidget *)));
 
     createActions();
     createMenus();
@@ -49,7 +62,7 @@ MainWindow::MainWindow()
 
 void MainWindow::closeEvent(QCloseEvent *event)
 {
-    workspace->closeAllWindows();
+    mdiArea->closeAllSubWindows();
     if (activeMdiChild()) {
         event->ignore();
     } else {
@@ -69,9 +82,9 @@ void MainWindow::open()
 {
     QString fileName = QFileDialog::getOpenFileName(this);
     if (!fileName.isEmpty()) {
-        MdiChild *existing = findMdiChild(fileName);
+        QMdiSubWindow *existing = findMdiChild(fileName);
         if (existing) {
-            workspace->setActiveWindow(existing);
+            mdiArea->setActiveSubWindow(existing);
             return;
         }
 
@@ -87,29 +100,32 @@ void MainWindow::open()
 
 void MainWindow::save()
 {
-    if (activeMdiChild()->save())
+    if (activeMdiChild() && activeMdiChild()->save())
         statusBar()->showMessage(tr("File saved"), 2000);
 }
 
 void MainWindow::saveAs()
 {
-    if (activeMdiChild()->saveAs())
+    if (activeMdiChild() && activeMdiChild()->saveAs())
         statusBar()->showMessage(tr("File saved"), 2000);
 }
 
 void MainWindow::cut()
 {
-    activeMdiChild()->cut();
+    if (activeMdiChild())
+        activeMdiChild()->cut();
 }
 
 void MainWindow::copy()
 {
-    activeMdiChild()->copy();
+    if (activeMdiChild())
+        activeMdiChild()->copy();
 }
 
 void MainWindow::paste()
 {
-    activeMdiChild()->paste();
+    if (activeMdiChild())
+        activeMdiChild()->paste();
 }
 
 void MainWindow::about()
@@ -129,7 +145,6 @@ void MainWindow::updateMenus()
     closeAllAct->setEnabled(hasMdiChild);
     tileAct->setEnabled(hasMdiChild);
     cascadeAct->setEnabled(hasMdiChild);
-    arrangeAct->setEnabled(hasMdiChild);
     nextAct->setEnabled(hasMdiChild);
     previousAct->setEnabled(hasMdiChild);
     separatorAct->setVisible(hasMdiChild);
@@ -148,17 +163,16 @@ void MainWindow::updateWindowMenu()
     windowMenu->addSeparator();
     windowMenu->addAction(tileAct);
     windowMenu->addAction(cascadeAct);
-    windowMenu->addAction(arrangeAct);
     windowMenu->addSeparator();
     windowMenu->addAction(nextAct);
     windowMenu->addAction(previousAct);
     windowMenu->addAction(separatorAct);
 
-    QList<QWidget *> windows = workspace->windowList();
+    QList<QMdiSubWindow *> windows = mdiArea->subWindowList();
     separatorAct->setVisible(!windows.isEmpty());
 
     for (int i = 0; i < windows.size(); ++i) {
-        MdiChild *child = qobject_cast<MdiChild *>(windows.at(i));
+        MdiChild *child = qobject_cast<MdiChild *>(windows.at(i)->widget());
 
         QString text;
         if (i < 9) {
@@ -172,14 +186,14 @@ void MainWindow::updateWindowMenu()
         action->setCheckable(true);
         action ->setChecked(child == activeMdiChild());
         connect(action, SIGNAL(triggered()), windowMapper, SLOT(map()));
-        windowMapper->setMapping(action, child);
+        windowMapper->setMapping(action, windows.at(i));
     }
 }
 
 MdiChild *MainWindow::createMdiChild()
 {
     MdiChild *child = new MdiChild;
-    workspace->addWindow(child);
+    mdiArea->addSubWindow(child);
 
     connect(child, SIGNAL(copyAvailable(bool)),
             cutAct, SLOT(setEnabled(bool)));
@@ -237,37 +251,31 @@ void MainWindow::createActions()
     closeAct->setShortcut(tr("Ctrl+F4"));
     closeAct->setStatusTip(tr("Close the active window"));
     connect(closeAct, SIGNAL(triggered()),
-            workspace, SLOT(closeActiveWindow()));
+            mdiArea, SLOT(closeActiveSubWindow()));
 
     closeAllAct = new QAction(tr("Close &All"), this);
     closeAllAct->setStatusTip(tr("Close all the windows"));
     connect(closeAllAct, SIGNAL(triggered()),
-            workspace, SLOT(closeAllWindows()));
+            mdiArea, SLOT(closeAllSubWindows()));
 
     tileAct = new QAction(tr("&Tile"), this);
     tileAct->setStatusTip(tr("Tile the windows"));
-    connect(tileAct, SIGNAL(triggered()), workspace, SLOT(tile()));
+    connect(tileAct, SIGNAL(triggered()), mdiArea, SLOT(tileSubWindows()));
 
     cascadeAct = new QAction(tr("&Cascade"), this);
     cascadeAct->setStatusTip(tr("Cascade the windows"));
-    connect(cascadeAct, SIGNAL(triggered()), workspace, SLOT(cascade()));
-
-    arrangeAct = new QAction(tr("Arrange &icons"), this);
-    arrangeAct->setStatusTip(tr("Arrange the icons"));
-    connect(arrangeAct, SIGNAL(triggered()), workspace, SLOT(arrangeIcons()));
+    connect(cascadeAct, SIGNAL(triggered()), mdiArea, SLOT(cascadeSubWindows()));
 
     nextAct = new QAction(tr("Ne&xt"), this);
-    nextAct->setShortcut(tr("Ctrl+F6"));
     nextAct->setStatusTip(tr("Move the focus to the next window"));
     connect(nextAct, SIGNAL(triggered()),
-            workspace, SLOT(activateNextWindow()));
+            mdiArea, SLOT(activateNextSubWindow()));
 
     previousAct = new QAction(tr("Pre&vious"), this);
-    previousAct->setShortcut(tr("Ctrl+Shift+F6"));
     previousAct->setStatusTip(tr("Move the focus to the previous "
                                  "window"));
     connect(previousAct, SIGNAL(triggered()),
-            workspace, SLOT(activatePreviousWindow()));
+            mdiArea, SLOT(activatePreviousSubWindow()));
 
     separatorAct = new QAction(this);
     separatorAct->setSeparator(true);
@@ -289,6 +297,8 @@ void MainWindow::createMenus()
     fileMenu->addAction(saveAct);
     fileMenu->addAction(saveAsAct);
     fileMenu->addSeparator();
+    QAction *action = fileMenu->addAction(tr("Switch layout direction"));
+    connect(action, SIGNAL(triggered()), this, SLOT(switchLayoutDirection()));
     fileMenu->addAction(exitAct);
 
     editMenu = menuBar()->addMenu(tr("&Edit"));
@@ -343,17 +353,34 @@ void MainWindow::writeSettings()
 
 MdiChild *MainWindow::activeMdiChild()
 {
-    return qobject_cast<MdiChild *>(workspace->activeWindow());
+    if (QMdiSubWindow *activeSubWindow = mdiArea->activeSubWindow())
+        return qobject_cast<MdiChild *>(activeSubWindow->widget());
+    return 0;
 }
 
-MdiChild *MainWindow::findMdiChild(const QString &fileName)
+QMdiSubWindow *MainWindow::findMdiChild(const QString &fileName)
 {
     QString canonicalFilePath = QFileInfo(fileName).canonicalFilePath();
 
-    foreach (QWidget *window, workspace->windowList()) {
-        MdiChild *mdiChild = qobject_cast<MdiChild *>(window);
+    foreach (QMdiSubWindow *window, mdiArea->subWindowList()) {
+        MdiChild *mdiChild = qobject_cast<MdiChild *>(window->widget());
         if (mdiChild->currentFile() == canonicalFilePath)
-            return mdiChild;
+            return window;
     }
     return 0;
 }
+
+void MainWindow::switchLayoutDirection()
+{
+    if (layoutDirection() == Qt::LeftToRight)
+        qApp->setLayoutDirection(Qt::RightToLeft);
+    else
+        qApp->setLayoutDirection(Qt::LeftToRight);
+}
+
+void MainWindow::setActiveSubWindow(QWidget *window)
+{
+    if (!window)
+        return;
+    mdiArea->setActiveSubWindow(qobject_cast<QMdiSubWindow *>(window));
+}
