@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2004-2006 Trolltech ASA. All rights reserved.
+** Copyright (C) 2004-2007 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
@@ -9,12 +9,25 @@
 ** and appearing in the file LICENSE.GPL included in the packaging of
 ** this file.  Please review the following information to ensure GNU
 ** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** http://trolltech.com/products/qt/licenses/licensing/opensource/
 **
 ** If you are unsure which license is appropriate for your use, please
 ** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
+** or contact the sales department at sales@trolltech.com.
+**
+** In addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.0, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
+**
+** In addition, as a special exception, Trolltech, as the sole copyright
+** holder for Qt Designer, grants users of the Qt/Eclipse Integration
+** plug-in the right for the Qt/Eclipse Integration to link to
+** functionality provided by Qt Designer and its related libraries.
+**
+** Trolltech reserves all rights not expressly granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -25,11 +38,12 @@
 #include <QtNetwork>
 
 #include "httpwindow.h"
+#include "ui_authenticationdialog.h"
 
 HttpWindow::HttpWindow(QWidget *parent)
     : QDialog(parent)
 {
-    urlLineEdit = new QLineEdit("http://www.ietf.org/iesg/1rfc_index.txt");
+    urlLineEdit = new QLineEdit("https://");
 
     urlLabel = new QLabel(tr("&URL:"));
     urlLabel->setBuddy(urlLineEdit);
@@ -37,8 +51,9 @@ HttpWindow::HttpWindow(QWidget *parent)
                                 "download."));
 
     downloadButton = new QPushButton(tr("Download"));
-    quitButton = new QPushButton(tr("Quit"));
     downloadButton->setDefault(true);
+    quitButton = new QPushButton(tr("Quit"));
+    quitButton->setAutoDefault(false);
 
     buttonBox = new QDialogButtonBox;
     buttonBox->addButton(downloadButton, QDialogButtonBox::ActionRole);
@@ -56,6 +71,8 @@ HttpWindow::HttpWindow(QWidget *parent)
             this, SLOT(updateDataReadProgress(int, int)));
     connect(http, SIGNAL(responseHeaderReceived(const QHttpResponseHeader &)),
             this, SLOT(readResponseHeader(const QHttpResponseHeader &)));
+    connect(http, SIGNAL(authenticationRequired(const QString &, quint16, QAuthenticator *)),
+            this, SLOT(slotAuthenticationRequired(const QString &, quint16, QAuthenticator *)));
     connect(progressDialog, SIGNAL(canceled()), this, SLOT(cancelDownload()));
     connect(downloadButton, SIGNAL(clicked()), this, SLOT(downloadFile()));
     connect(quitButton, SIGNAL(clicked()), this, SLOT(close()));
@@ -79,13 +96,17 @@ void HttpWindow::downloadFile()
     QUrl url(urlLineEdit->text());
     QFileInfo fileInfo(url.path());
     QString fileName = fileInfo.fileName();
+    if (fileName.isEmpty())
+        fileName = "index.html";
 
     if (QFile::exists(fileName)) {
-        QMessageBox::information(this, tr("HTTP"),
-                                 tr("There already exists a file called %1 in "
-                                    "the current directory.")
-                                 .arg(fileName));
-        return;
+        if (QMessageBox::question(this, tr("HTTP"), 
+                                  tr("There already exists a file called %1 in "
+                                     "the current directory. Overwrite?").arg(fileName),
+                                  QMessageBox::Ok|QMessageBox::Cancel, QMessageBox::Cancel)
+            == QMessageBox::Cancel)
+            return;
+        QFile::remove(fileName);
     }
 
     file = new QFile(fileName);
@@ -98,7 +119,9 @@ void HttpWindow::downloadFile()
         return;
     }
 
-    http->setHost(url.host(), url.port() != -1 ? url.port() : 80);
+    QHttp::ConnectionMode mode = url.scheme().toLower() == "https" ? QHttp::ConnectionModeHttps : QHttp::ConnectionModeHttp;
+    http->setHost(url.host(), mode, url.port() == -1 ? 0 : url.port());
+    
     if (!url.userName().isEmpty())
         http->setUser(url.userName(), url.password());
 
@@ -120,6 +143,8 @@ void HttpWindow::cancelDownload()
 
 void HttpWindow::httpRequestFinished(int requestId, bool error)
 {
+    if (requestId != httpGetId)
+        return;
     if (httpRequestAborted) {
         if (file) {
             file->close();
@@ -179,3 +204,17 @@ void HttpWindow::enableDownloadButton()
 {
     downloadButton->setEnabled(!urlLineEdit->text().isEmpty());
 }
+
+void HttpWindow::slotAuthenticationRequired(const QString &hostName, quint16, QAuthenticator *authenticator)
+{
+    QDialog dlg;
+    Ui::Dialog ui;
+    ui.setupUi(&dlg);
+    dlg.adjustSize();
+    ui.siteDescription->setText(tr("%1 at %2").arg(authenticator->realm()).arg(hostName));
+    
+    if (dlg.exec() == QDialog::Accepted) {
+        authenticator->setUser(ui.userEdit->text());
+        authenticator->setPassword(ui.passwordEdit->text());
+    }
+}
