@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2004-2006 Trolltech AS. All rights reserved.
+** Copyright (C) 2004-2007 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
@@ -9,12 +9,25 @@
 ** and appearing in the file LICENSE.GPL included in the packaging of
 ** this file.  Please review the following information to ensure GNU
 ** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** http://trolltech.com/products/qt/licenses/licensing/opensource/
 **
 ** If you are unsure which license is appropriate for your use, please
 ** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
+** or contact the sales department at sales@trolltech.com.
+**
+** In addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.0, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
+**
+** In addition, as a special exception, Trolltech, as the sole copyright
+** holder for Qt Designer, grants users of the Qt/Eclipse Integration
+** plug-in the right for the Qt/Eclipse Integration to link to
+** functionality provided by Qt Designer and its related libraries.
+**
+** Trolltech reserves all rights not expressly granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -37,25 +50,19 @@ PreviewForm::PreviewForm(QWidget *parent)
     textEdit->setLineWrapMode(QTextEdit::NoWrap);
     textEdit->setReadOnly(true);
 
-    okButton = new QPushButton(tr("OK"));
-    cancelButton = new QPushButton(tr("Cancel"));
-    okButton->setDefault(true);
+    buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok
+                                    | QDialogButtonBox::Cancel);
 
     connect(encodingComboBox, SIGNAL(activated(int)),
             this, SLOT(updateTextEdit()));
-    connect(okButton, SIGNAL(clicked()), this, SLOT(accept()));
-    connect(cancelButton, SIGNAL(clicked()), this, SLOT(reject()));
-
-    QHBoxLayout *buttonLayout = new QHBoxLayout;
-    buttonLayout->addStretch(1);
-    buttonLayout->addWidget(okButton);
-    buttonLayout->addWidget(cancelButton);
+    connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
+    connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
 
     QGridLayout *mainLayout = new QGridLayout;
     mainLayout->addWidget(encodingLabel, 0, 0);
     mainLayout->addWidget(encodingComboBox, 0, 1);
     mainLayout->addWidget(textEdit, 1, 0, 1, 2);
-    mainLayout->addLayout(buttonLayout, 2, 0, 1, 2);
+    mainLayout->addWidget(buttonBox, 2, 0, 1, 2);
     setLayout(mainLayout);
 
     setWindowTitle(tr("Choose Encoding"));
