@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2006-2006 Trolltech ASA. All rights reserved.
+** Copyright (C) 2006-2007 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
@@ -9,12 +9,25 @@
 ** and appearing in the file LICENSE.GPL included in the packaging of
 ** this file.  Please review the following information to ensure GNU
 ** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** http://trolltech.com/products/qt/licenses/licensing/opensource/
 **
 ** If you are unsure which license is appropriate for your use, please
 ** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
+** or contact the sales department at sales@trolltech.com.
+**
+** In addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.0, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
+**
+** In addition, as a special exception, Trolltech, as the sole copyright
+** holder for Qt Designer, grants users of the Qt/Eclipse Integration
+** plug-in the right for the Qt/Eclipse Integration to link to
+** functionality provided by Qt Designer and its related libraries.
+**
+** Trolltech reserves all rights not expressly granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -26,12 +39,12 @@
 #include "mainwindow.h"
 
 MainWindow::MainWindow(QWidget *parent)
-    : QMainWindow(parent), completer(0), comboBox(0), lineEdit(0)
+    : QMainWindow(parent), completer(0), lineEdit(0)
 {
     createMenu();
 
     QWidget *centralWidget = new QWidget;
-    
+
     QLabel *modelLabel = new QLabel;
     modelLabel->setText(tr("Model"));
 
@@ -55,51 +68,48 @@ MainWindow::MainWindow(QWidget *parent)
     caseCombo = new QComboBox;
     caseCombo->addItem(tr("Case Insensitive"));
     caseCombo->addItem(tr("Case Sensitive"));
-#ifdef Q_OS_WIN
     caseCombo->setCurrentIndex(0);
-#else
-    caseCombo->setCurrentIndex(1);
-#endif
+
+    wrapCheckBox = new QCheckBox;
+    wrapCheckBox->setText(tr("Wrap around completions"));
+    wrapCheckBox->setChecked(true);
 
     contentsLabel = new QLabel;
     contentsLabel->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
 
-    connect(modelCombo, SIGNAL(activated(int)), this, SLOT(updateModel()));
+    connect(modelCombo, SIGNAL(activated(int)), this, SLOT(changeModel()));
     connect(modeCombo, SIGNAL(activated(int)), this, SLOT(changeMode(int)));
     connect(caseCombo, SIGNAL(activated(int)), this, SLOT(changeCase(int)));
+
+    lineEdit = new QLineEdit;
     
-    QGridLayout *layout = new QGridLayout; 
+    QGridLayout *layout = new QGridLayout;
     layout->addWidget(modelLabel, 0, 0); layout->addWidget(modelCombo, 0, 1);
     layout->addWidget(modeLabel, 1, 0);  layout->addWidget(modeCombo, 1, 1);
     layout->addWidget(caseLabel, 2, 0);  layout->addWidget(caseCombo, 2, 1);
-    layout->addWidget(contentsLabel, 3, 0, 1, 2);
+    layout->addWidget(wrapCheckBox, 3, 0);
+    layout->addWidget(contentsLabel, 4, 0, 1, 2);
+    layout->addWidget(lineEdit, 5, 0, 1, 2);
     centralWidget->setLayout(layout);
     setCentralWidget(centralWidget);
 
-    useComboBox(false);
-    updateModel();
-    changeCase(caseCombo->currentIndex());
-    changeMode(modeCombo->currentIndex());
+    changeModel();
 
     setWindowTitle(tr("Completer"));
+    lineEdit->setFocus();
 }
 
 void MainWindow::createMenu()
 {
-    QAction *comboAction = new QAction(tr("Show QComboBox"), this);
-    comboAction->setCheckable(true);
     QAction *exitAction = new QAction(tr("Exit"), this);
     QAction *aboutAct = new QAction(tr("About"), this);
     QAction *aboutQtAct = new QAction(tr("About Qt"), this);
 
-    connect(comboAction, SIGNAL(toggled(bool)), this, SLOT(useComboBox(bool)));
     connect(exitAction, SIGNAL(triggered()), qApp, SLOT(quit()));
     connect(aboutAct, SIGNAL(triggered()), this, SLOT(about()));
     connect(aboutQtAct, SIGNAL(triggered()), qApp, SLOT(aboutQt()));
 
     QMenu* fileMenu = menuBar()->addMenu(tr("File"));
-    fileMenu->addAction(comboAction);
-    fileMenu->addSeparator();
     fileMenu->addAction(exitAction);
 
     QMenu* helpMenu = menuBar()->addMenu(tr("About"));
@@ -107,19 +117,6 @@ void MainWindow::createMenu()
     helpMenu->addAction(aboutQtAct);
 }
 
-void MainWindow::changeMode(int index)
-{
-    QCompleter::CompletionMode mode;
-    if (index == 0)
-        mode = QCompleter::InlineCompletion;
-    else if (index == 1)
-        mode = QCompleter::PopupCompletion;
-    else
-        mode = QCompleter::UnfilteredPopupCompletion;
-
-    completer->setCompletionMode(mode);
-}
-
 QAbstractItemModel *MainWindow::modelFromFile(const QString& fileName)
 {
     QFile file(fileName);
@@ -128,7 +125,7 @@ QAbstractItemModel *MainWindow::modelFromFile(const QString& fileName)
 
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
     QStringList words;
-    
+
     while (!file.atEnd()) {
         QByteArray line = file.readLine();
         if (!line.isEmpty())
@@ -151,18 +148,32 @@ QAbstractItemModel *MainWindow::modelFromFile(const QString& fileName)
         m->setData(countryIdx, country);
         m->setData(symbolIdx, symbol);
     }
-    
+
     return m;
 }
 
-void MainWindow::updateModel()
+void MainWindow::changeMode(int index)
 {
-    if (completer) {
-        comboBox ? comboBox->setCompleter(0) : lineEdit->setCompleter(0);
-        delete completer;
-    }
+    QCompleter::CompletionMode mode;
+    if (index == 0)
+        mode = QCompleter::InlineCompletion;
+    else if (index == 1)
+        mode = QCompleter::PopupCompletion;
+    else
+        mode = QCompleter::UnfilteredPopupCompletion;
+
+    completer->setCompletionMode(mode);
+}
+
+void MainWindow::changeCase(int cs)
+{
+    completer->setCaseSensitivity(cs ? Qt::CaseSensitive : Qt::CaseInsensitive);
+}
+
+void MainWindow::changeModel()
+{
+    delete completer;
     completer = new QCompleter(this);
-    comboBox ? comboBox->setCompleter(completer) : lineEdit->setCompleter(completer);
 
     switch (modelCombo->currentIndex()) {
     default:
@@ -202,30 +213,11 @@ void MainWindow::updateModel()
         break;
     }
 
-    changeCase(caseCombo->currentIndex());
     changeMode(modeCombo->currentIndex());
-}
-
-void MainWindow::useComboBox(bool combo)
-{
-    if ((comboBox && combo) || (lineEdit && !combo))
-        return;
-    if (combo) {
-        delete lineEdit;
-        lineEdit = 0;
-        comboBox = new QComboBox;
-        comboBox->setEditable(true);
-        comboBox->setCompleter(completer);
-        (static_cast<QGridLayout *>(centralWidget()->layout()))->addWidget(comboBox, 4, 0, 1, 2);
-        comboBox->setFocus();
-    } else {
-        delete comboBox;
-        comboBox = 0;
-        lineEdit = new QLineEdit;
-        lineEdit->setCompleter(completer);
-        (static_cast<QGridLayout *>(centralWidget()->layout()))->addWidget(lineEdit, 4, 0, 1, 2);
-        lineEdit->setFocus();
-    }
+    changeCase(caseCombo->currentIndex());
+    completer->setWrapAround(wrapCheckBox->isChecked());
+    lineEdit->setCompleter(completer);
+    connect(wrapCheckBox, SIGNAL(clicked(bool)), completer, SLOT(setWrapAround(bool)));
 }
 
 void MainWindow::about()
@@ -233,8 +225,3 @@ void MainWindow::about()
     QMessageBox::about(this, tr("About"), tr("This example demonstrates the "
         "different features of the QCompleter class."));
 }
-
-void MainWindow::changeCase(int cs)
-{
-    completer->setCaseSensitivity(cs ? Qt::CaseSensitive : Qt::CaseInsensitive);
-}
