@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2004-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 2004-2007 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
@@ -9,12 +9,25 @@
 ** and appearing in the file LICENSE.GPL included in the packaging of
 ** this file.  Please review the following information to ensure GNU
 ** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** http://trolltech.com/products/qt/licenses/licensing/opensource/
 **
 ** If you are unsure which license is appropriate for your use, please
 ** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
+** or contact the sales department at sales@trolltech.com.
+**
+** In addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.0, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
+**
+** In addition, as a special exception, Trolltech, as the sole copyright
+** holder for Qt Designer, grants users of the Qt/Eclipse Integration
+** plug-in the right for the Qt/Eclipse Integration to link to
+** functionality provided by Qt Designer and its related libraries.
+**
+** Trolltech reserves all rights not expressly granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -33,6 +46,7 @@ Window::Window()
     QComboBox *echoComboBox = new QComboBox;
     echoComboBox->addItem(tr("Normal"));
     echoComboBox->addItem(tr("Password"));
+    echoComboBox->addItem(tr("PasswordEchoOnEdit"));
     echoComboBox->addItem(tr("No Echo"));
 
     echoLineEdit = new QLineEdit;
@@ -79,15 +93,15 @@ Window::Window()
     accessLineEdit = new QLineEdit;
 
     connect(echoComboBox, SIGNAL(activated(int)),
-            this, SLOT(slotEchoChanged(int)));
+            this, SLOT(echoChanged(int)));
     connect(validatorComboBox, SIGNAL(activated(int)),
-            this, SLOT(slotValidatorChanged(int)));
+            this, SLOT(validatorChanged(int)));
     connect(alignmentComboBox, SIGNAL(activated(int)),
-            this, SLOT(slotAlignmentChanged(int)));
+            this, SLOT(alignmentChanged(int)));
     connect(inputMaskComboBox, SIGNAL(activated(int)),
-            this, SLOT(slotInputMaskChanged(int)));
+            this, SLOT(inputMaskChanged(int)));
     connect(accessComboBox, SIGNAL(activated(int)),
-            this, SLOT(slotAccessChanged(int)));
+            this, SLOT(accessChanged(int)));
 
     QGridLayout *echoLayout = new QGridLayout;
     echoLayout->addWidget(echoLabel, 0, 0);
@@ -119,18 +133,18 @@ Window::Window()
     accessLayout->addWidget(accessLineEdit, 1, 0, 1, 2);
     accessGroup->setLayout(accessLayout);
 
-    QVBoxLayout *layout = new QVBoxLayout;
-    layout->addWidget(echoGroup);
-    layout->addWidget(validatorGroup);
-    layout->addWidget(alignmentGroup);
-    layout->addWidget(inputMaskGroup);
-    layout->addWidget(accessGroup);
+    QGridLayout *layout = new QGridLayout;
+    layout->addWidget(echoGroup, 0, 0);
+    layout->addWidget(validatorGroup, 1, 0);
+    layout->addWidget(alignmentGroup, 2, 0);
+    layout->addWidget(inputMaskGroup, 0, 1);
+    layout->addWidget(accessGroup, 1, 1);
     setLayout(layout);
 
     setWindowTitle(tr("Line Edits"));
 }
 
-void Window::slotEchoChanged(int index)
+void Window::echoChanged(int index)
 {
     switch (index) {
     case 0:
@@ -140,11 +154,14 @@ void Window::slotEchoChanged(int index)
         echoLineEdit->setEchoMode(QLineEdit::Password);
         break;
     case 2:
-    	echoLineEdit->setEchoMode(QLineEdit::NoEcho);
+    	echoLineEdit->setEchoMode(QLineEdit::PasswordEchoOnEdit);
+        break;
+    case 3:
+        echoLineEdit->setEchoMode(QLineEdit::NoEcho);
     }
 }
 
-void Window::slotValidatorChanged(int index)
+void Window::validatorChanged(int index)
 {
     switch (index) {
     case 0:
@@ -159,10 +176,10 @@ void Window::slotValidatorChanged(int index)
             999.0, 2, validatorLineEdit));
     }
 
-    validatorLineEdit->setText("");
+    validatorLineEdit->clear();
 }
 
-void Window::slotAlignmentChanged(int index)
+void Window::alignmentChanged(int index)
 {
     switch (index) {
     case 0:
@@ -176,7 +193,7 @@ void Window::slotAlignmentChanged(int index)
     }
 }
 
-void Window::slotInputMaskChanged(int index)
+void Window::inputMaskChanged(int index)
 {
     switch (index) {
     case 0:
@@ -195,7 +212,7 @@ void Window::slotInputMaskChanged(int index)
     }
 }
 
-void Window::slotAccessChanged(int index)
+void Window::accessChanged(int index)
 {
     switch (index) {
     case 0:
