@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 2005-2007 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
@@ -9,12 +9,25 @@
 ** and appearing in the file LICENSE.GPL included in the packaging of
 ** this file.  Please review the following information to ensure GNU
 ** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** http://trolltech.com/products/qt/licenses/licensing/opensource/
 **
 ** If you are unsure which license is appropriate for your use, please
 ** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
+** or contact the sales department at sales@trolltech.com.
+**
+** In addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.0, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
+**
+** In addition, as a special exception, Trolltech, as the sole copyright
+** holder for Qt Designer, grants users of the Qt/Eclipse Integration
+** plug-in the right for the Qt/Eclipse Integration to link to
+** functionality provided by Qt Designer and its related libraries.
+**
+** Trolltech reserves all rights not expressly granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -91,9 +104,10 @@ void ControllerWindow::updatePreview()
         flags |= Qt::WindowShadeButtonHint;
     if (windowStaysOnTopCheckBox->isChecked())
         flags |= Qt::WindowStaysOnTopHint;
+    if (customizeWindowHintCheckBox->isChecked())
+        flags |= Qt::CustomizeWindowHint;
 
     previewWindow->setWindowFlags(flags);
-    previewWindow->show();
 
     QPoint pos = previewWindow->pos();
     if (pos.x() < 0)
@@ -101,6 +115,7 @@ void ControllerWindow::updatePreview()
     if (pos.y() < 0)
         pos.setY(0);
     previewWindow->move(pos);
+    previewWindow->show();
 }
 
 void ControllerWindow::createTypeGroupBox()
@@ -146,6 +161,7 @@ void ControllerWindow::createHintsGroupBox()
             createCheckBox(tr("Window context help button"));
     windowShadeButtonCheckBox = createCheckBox(tr("Window shade button"));
     windowStaysOnTopCheckBox = createCheckBox(tr("Window stays on top"));
+    customizeWindowHintCheckBox= createCheckBox(tr("Customize window"));
 
     QGridLayout *layout = new QGridLayout;
     layout->addWidget(msWindowsFixedSizeDialogCheckBox, 0, 0);
@@ -158,6 +174,7 @@ void ControllerWindow::createHintsGroupBox()
     layout->addWidget(windowContextHelpButtonCheckBox, 2, 1);
     layout->addWidget(windowShadeButtonCheckBox, 3, 1);
     layout->addWidget(windowStaysOnTopCheckBox, 4, 1);
+    layout->addWidget(customizeWindowHintCheckBox, 5, 0);
     hintsGroupBox->setLayout(layout);
 }
 
